@@ -9,73 +9,14 @@
         <source>About</source>
         <translation>Over</translation>
     </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;https://github.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&lt;html&gt;&lt;head&gt;&lt;style&gt;li {font-size: 10pt}&lt;/style&gt;&lt;/head&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Project Maintainers:&lt;/span&gt;&lt;/p&gt;&lt;ul&gt;&lt;li&gt;droidmonkey&lt;/li&gt;&lt;li&gt;phoerious&lt;/li&gt;&lt;li&gt;TheZ3ro&lt;/li&gt;&lt;li&gt;louib&lt;/li&gt;&lt;li&gt;Weslly&lt;/li&gt;&lt;li&gt;debfx (KeePassX)&lt;/li&gt;&lt;/ul&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Contributors</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>&lt;html&gt;&lt;body&gt;
-            &lt;p style=&quot;font-size:x-large; font-weight:600;&quot;&gt;Code:&lt;/p&gt;
-            &lt;ul&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;debfx (KeePassX)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;BlueIce (KeePassX)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;droidmonkey&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;phoerious&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;TheZ3ro&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;louib&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;weslly&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;keithbennett (KeePassHTTP)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;Typz (KeePassHTTP)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;denk-mal (KeePassHTTP)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;kylemanna (YubiKey)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;seatedscribe (CSV Importer)&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;pgalves (Inline Messages)&lt;/li&gt;
-            &lt;/ul&gt;
-            &lt;p style=&quot;font-size:x-large; font-weight:600;&quot;&gt;Translations:&lt;/p&gt;
-            &lt;ul&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Chinese:&lt;/span&gt; Biggulu, ligyxy, BestSteve&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Czech:&lt;/span&gt; pavelb, JosefVitu&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Dutch:&lt;/span&gt; Vistaus, KnooL, apie&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Finnish:&lt;/span&gt; MawKKe&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;French:&lt;/span&gt; Scrat15, frgnca, gilbsgilbs, gtalbot, iannick, kyodev, logut&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;German:&lt;/span&gt; Calyrx, DavidHamburg, antsas, codejunky, jensrutschmann, montilo, omnisome4, origin_de, pcrcoding, phoerious, rgloor, vlenzer&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Greek:&lt;/span&gt; nplatis&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Italian:&lt;/span&gt; TheZ3ro, FranzMari, Mte90, tosky&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Kazakh:&lt;/span&gt; sotrud_nik&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Lithuanian:&lt;/span&gt; Moo&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Polish:&lt;/span&gt; konradmb, mrerexx&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Portuguese: &lt;/span&gt;vitor895, weslly, American_Jesus, mihai.ile&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Russian:&lt;/span&gt; vsvyatski, KekcuHa, wkill95&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Spanish:&lt;/span&gt; EdwardNavarro, antifaz, piegope, pquin, vsvyatski&lt;/li&gt;
-            &lt;li style=&quot;font-size:10pt&quot;&gt;&lt;span style=&quot;font-weight:600;&quot;&gt;Swedish:&lt;/span&gt; henziger&lt;/li&gt;
-            &lt;/ul&gt;
-            &lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;See Contributions on GitHub&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Debug Info</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Include the following information whenever you report a bug:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Copy to clipboard</source>
         <translation type="unfinished"/>
@@ -103,6 +44,30 @@ Kernel: %3 %4</source>
         <source>Enabled extensions:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
+        <translation>KeePassXC wordt verspreid onder de voorwaarden van de GNU General Public License (GPL) versie 2 of (als u wenst) versie 3.</translation>
+    </message>
+    <message>
+        <source>Project Maintainers:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Include the following information whenever you report a bug:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Distribution: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AccessControlDialog</name>
@@ -249,10 +214,6 @@ Geef aan of u toegang wilt toestaan of niet.</translation>
         <source>Clone Options</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Append &apos; - Copy&apos; to title</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Replace username and password with references</source>
         <translation type="unfinished"/>
@@ -261,6 +222,10 @@ Geef aan of u toegang wilt toestaan of niet.</translation>
         <source>Copy history</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Append &apos; - Clone&apos; to title</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>CsvImportWidget</name>
@@ -1095,10 +1060,6 @@ Wilt u toch doorgaan met openen?</translation>
         <source>Select Image</source>
         <translation>Kies afbeelding</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Fout</translation>
-    </message>
     <message>
         <source>Download favicon</source>
         <translation>Favicon downloaden</translation>
@@ -1127,6 +1088,14 @@ Wilt u toch doorgaan met openen?</translation>
         <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Custom icon already exists</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>EditWidgetProperties</name>
@@ -1333,20 +1302,28 @@ Wilt u toch doorgaan met openen?</translation>
         <source>Unable to calculate master key</source>
         <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
     </message>
+    <message>
+        <source>Unable to issue challenge-response.</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>The selected file is an old KeePass 1 database (.kdb).
 
-You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
+You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
 This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
-        <translation>Het gekozen bestand is een oude KeePass 1 database (.kdb).
-
-U kunt het importeren door te klikken op Database &gt; &apos;KeePass 1 database importeren&apos;.
-Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen met KeePassX 0.4.</translation>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>KeePass2Writer</name>
     <message>
         <source>Unable to issue challenge-response.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Unable to calculate master key</source>
+        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
+    </message>
 </context>
 <context>
     <name>Main</name>
@@ -1366,6 +1343,10 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>Another instance of KeePassXC is already running.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -1421,10 +1402,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>&amp;Recent databases</source>
         <translation>&amp;Recente databases</translation>
     </message>
-    <message>
-        <source>He&amp;lp</source>
-        <translation>He&amp;lp</translation>
-    </message>
     <message>
         <source>E&amp;ntries</source>
         <translation>Items</translation>
@@ -1449,10 +1426,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>&amp;About</source>
         <translation>&amp;Over</translation>
     </message>
-    <message>
-        <source>&amp;Open database</source>
-        <translation>&amp;Open database</translation>
-    </message>
     <message>
         <source>&amp;Save database</source>
         <translation>&amp;Sla database op</translation>
@@ -1493,14 +1466,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>&amp;Delete group</source>
         <translation>&amp;Verwijder groep</translation>
     </message>
-    <message>
-        <source>Sa&amp;ve database as</source>
-        <translation>Database opslaan als</translation>
-    </message>
-    <message>
-        <source>Change &amp;master key</source>
-        <translation>Wijzig &amp;hoofdsleutel</translation>
-    </message>
     <message>
         <source>&amp;Database settings</source>
         <translation>&amp;Database-instellingen</translation>
@@ -1513,10 +1478,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>Timed one-time password</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Setup TOTP</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Copy &amp;TOTP</source>
         <translation type="unfinished"/>
@@ -1565,14 +1526,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>&amp;Notes</source>
         <translation>&amp;Opmerkingen</translation>
     </message>
-    <message>
-        <source>&amp;Export to CSV file</source>
-        <translation>&amp;Naar CSV-bestand exporteren</translation>
-    </message>
-    <message>
-        <source>Re&amp;pair database</source>
-        <translation>Database repareren</translation>
-    </message>
     <message>
         <source>Password Generator</source>
         <translation>Wachtwoord generator</translation>
@@ -1593,14 +1546,6 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>&amp;Tools</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Import KeePass 1 database</source>
-        <translation>Importeer Keepass 1-database</translation>
-    </message>
-    <message>
-        <source>Import CSV file</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Empty recycle bin</source>
         <translation type="unfinished"/>
@@ -1617,6 +1562,42 @@ Deze actie is niet omkeerbaar. U kunt de geimporteerde database niet meer openen
         <source>Please touch the button on your YubiKey!</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Open database...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sa&amp;ve database as...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Change &amp;master key...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Export to CSV file...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import KeePass 1 database...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import CSV file...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Re&amp;pair database...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Set up TOTP...</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
@@ -2167,6 +2148,18 @@ Geef het een unieke identificerende naam en accepteer de associate wanneer je de
         <source>Always ask before performing Auto-Type</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Auto-Type delay</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source> ms</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Start only a single instance of KeePassXC</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SettingsWidgetSecurity</name>
@@ -2206,6 +2199,14 @@ Geef het een unieke identificerende naam en accepteer de associate wanneer je de
         <source>Lock databases when session is locked or lid is closed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Privacy</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Use Google as fallback for downloading website icons</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SetupTotpDialog</name>
