@@ -17,6 +17,8 @@
  */
 #include "Entry.h"
 
+#include "config-keepassx.h"
+
 #include "core/Database.h"
 #include "core/DatabaseIcons.h"
 #include "core/Group.h"
@@ -237,6 +239,11 @@ QString Entry::url() const
     return m_attributes->value(EntryAttributes::URLKey);
 }
 
+QString Entry::webUrl() const
+{
+    return resolveUrl(m_attributes->value(EntryAttributes::URLKey));
+}
+
 QString Entry::username() const
 {
     return m_attributes->value(EntryAttributes::UserNameKey);
@@ -720,6 +727,13 @@ const Database* Entry::database() const
     }
 }
 
+QString Entry::maskPasswordPlaceholders(const QString &str) const
+{
+    QString result = str;
+    result.replace(QRegExp("(\\{PASSWORD\\})", Qt::CaseInsensitive, QRegExp::RegExp2), "******");
+    return result;
+}
+
 QString Entry::resolveMultiplePlaceholders(const QString& str) const
 {
     QString result = str;
@@ -784,3 +798,34 @@ QString Entry::resolvePlaceholder(const QString& str) const
 
     return result;
 }
+
+QString Entry::resolveUrl(const QString& url) const
+{
+    QString newUrl = url;
+    if (!url.isEmpty() && !url.contains("://")) {
+        // URL doesn't have a protocol, add https by default
+        newUrl.prepend("https://");
+    }
+
+    if (newUrl.startsWith("cmd://")) {
+        QStringList cmdList = newUrl.split(" ");
+        for (int i=1; i < cmdList.size(); ++i) {
+            // Don't pass arguments to the resolveUrl function (they look like URL's)
+            if (!cmdList[i].startsWith("-") && !cmdList[i].startsWith("/")) {
+                return resolveUrl(cmdList[i].remove(QRegExp("'|\"")));
+            }
+        }
+
+        // No URL in this command
+        return QString("");
+    }
+
+    // Validate the URL
+    QUrl tempUrl = QUrl(newUrl);
+    if (tempUrl.isValid() && (tempUrl.scheme() == "http" || tempUrl.scheme() == "https")) {
+        return tempUrl.url();
+    }
+
+    // No valid http URL's found
+    return QString("");
+}
